@@ -77,6 +77,7 @@ gst_va_decoder_set_property (GObject * object, guint prop_id,
 
   switch (prop_id) {
     case PROP_DISPLAY:{
+      /* G_PARAM_CONSTRUCT_ONLY */
       g_assert (!self->display);
       self->display = g_value_dup_object (value);
       break;
@@ -197,6 +198,8 @@ gst_va_decoder_new (GstVaDisplay * display, guint32 codec)
   g_return_val_if_fail (GST_IS_VA_DISPLAY (display), NULL);
 
   self = g_object_new (GST_TYPE_VA_DECODER, "display", display, NULL);
+  gst_object_ref_sink (self);
+
   if (!gst_va_decoder_initialize (self, codec))
     gst_clear_object (&self);
 
@@ -210,9 +213,7 @@ gst_va_decoder_is_open (GstVaDecoder * self)
 
   g_return_val_if_fail (GST_IS_VA_DECODER (self), FALSE);
 
-  GST_OBJECT_LOCK (self);
   ret = (self->config != VA_INVALID_ID && self->profile != VAProfileNone);
-  GST_OBJECT_UNLOCK (self);
   return ret;
 }
 
@@ -245,11 +246,9 @@ gst_va_decoder_open (GstVaDecoder * self, VAProfile profile, guint rt_format)
     return FALSE;
   }
 
-  GST_OBJECT_LOCK (self);
   self->config = config;
   self->profile = profile;
   self->rt_format = rt_format;
-  GST_OBJECT_UNLOCK (self);
 
   /* now we should return now only this profile's caps */
   gst_caps_replace (&self->srcpad_caps, NULL);
@@ -282,9 +281,7 @@ gst_va_decoder_close (GstVaDecoder * self)
     return FALSE;
   }
 
-  GST_OBJECT_LOCK (self);
   gst_va_decoder_init (self);
-  GST_OBJECT_UNLOCK (self);
 
   gst_caps_replace (&self->srcpad_caps, NULL);
   gst_caps_replace (&self->sinkpad_caps, NULL);
@@ -304,13 +301,10 @@ gst_va_decoder_set_frame_size_with_surfaces (GstVaDecoder * self,
 
   g_return_val_if_fail (GST_IS_VA_DECODER (self), FALSE);
 
-  GST_OBJECT_LOCK (self);
   if (self->context != VA_INVALID_ID) {
-    GST_OBJECT_UNLOCK (self);
     GST_INFO_OBJECT (self, "decoder already has a context");
     return TRUE;
   }
-  GST_OBJECT_UNLOCK (self);
 
   if (!gst_va_decoder_is_open (self)) {
     GST_ERROR_OBJECT (self, "decoder has not been opened yet");
@@ -332,11 +326,9 @@ gst_va_decoder_set_frame_size_with_surfaces (GstVaDecoder * self,
     return FALSE;
   }
 
-  GST_OBJECT_LOCK (self);
   self->context = context;
   self->coded_width = coded_width;
   self->coded_height = coded_height;
-  GST_OBJECT_UNLOCK (self);
 
   return TRUE;
 }
@@ -362,19 +354,13 @@ gst_va_decoder_update_frame_size (GstVaDecoder * self, gint coded_width,
     return FALSE;
   }
 
-  GST_OBJECT_LOCK (self);
   if (self->context == VA_INVALID_ID) {
-    GST_OBJECT_UNLOCK (self);
     GST_INFO_OBJECT (self, "decoder does not have a context");
     return FALSE;
   }
-  GST_OBJECT_UNLOCK (self);
 
-
-  GST_OBJECT_LOCK (self);
   self->coded_width = coded_width;
   self->coded_height = coded_height;
-  GST_OBJECT_UNLOCK (self);
 
   return TRUE;
 }
@@ -691,10 +677,8 @@ gst_va_decoder_config_is_equal (GstVaDecoder * self, VAProfile new_profile,
 
   /* @TODO: Check if current buffers are large enough, and reuse
    * them */
-  GST_OBJECT_LOCK (self);
   ret = (self->profile == new_profile && self->rt_format == new_rtformat
       && self->coded_width == new_width && self->coded_height == new_height);
-  GST_OBJECT_UNLOCK (self);
 
   return ret;
 }
@@ -708,7 +692,6 @@ gst_va_decoder_get_config (GstVaDecoder * self, VAProfile * profile,
   if (!gst_va_decoder_is_open (self))
     return FALSE;
 
-  GST_OBJECT_LOCK (self);
   if (profile)
     *profile = self->profile;
   if (rt_format)
@@ -717,7 +700,6 @@ gst_va_decoder_get_config (GstVaDecoder * self, VAProfile * profile,
     *width = self->coded_width;
   if (height)
     *height = self->coded_height;
-  GST_OBJECT_UNLOCK (self);
 
   return TRUE;
 }
